==> karentify-0.0.2.tar.gz: karentify-0.0.2/README.md <==
# ThIs iS KaReNtIfY!!!

uNlEaSh yOuR InNeR KaReN On a mEsSaGe!!!

mAkE SuRe, YoU ArE HeArD As a vAlUeD CuStOmEr bY UnLeAsHiNg yOuR InNeR KaReN!!!

## fEaTuReS!!!

* aLl sHoRt oPtIoNs aRe cApS OnLy!!!
* LoNg oPtIoNs aLl kArEnTiFiEd tO Be vErY ClEaR AbOuT ThEm!!!
* MuLtIpLe iNpUt fEeDs, Be iT!!!
** ...tHaT YoU WaNt tO StAtE YoUr vAlId dEmAnDs dIrEcTlY On tHe cOmMaNdLiNe!!!
** ...Or yOu wAnT To iNtErAcTiVeLy sTaTe tHeM!!!
** ...oR YoU WaNt tO RaIsE ThE SeRiOuSnEsS In aN ExIsTiNg bOdY Of tExT!!!
* DoCuMeNtAtIoN CoMeS FrOm a pOiNt oF EdUcAtEd aUtHoRiTy!!!

kArEnTiFy hAs yOu cOvErEd!!!

## uSe cAsEs!!!

### I WaNt tO MaKe mY PoInT VeRy cLeAr:!!!

```console
karen@localhost:~$ karentify is that clear? --dEmAnD-MaNaGeR
iS ThAt cLeAr!!!
AnD I WoUlD LiKe tO TaLk tO YoUr mAnAgEr!!!
karen@localhost:~$
```

NoTe tHe fEaTuRe oF Ai aSsIsTeT AuToMaTiC DoUbT ReMoVaL!!!

### My lOnG FoRm tExT NeEdS AuThOrItY:!!!

```console
karen@localhost:~$ cat lipsum.txt | fold | karentify --dEmAnD-MaNaGeR
LoReM IpSuM DoLoR SiT AmEt, CoNsEtEtUr sAdIpScInG ElItR, sEd dIaM NoNuMy eIrMoD!!!
tEmPoR InViDuNt uT LaBoRe eT DoLoRe mAgNa aLiQuYaM ErAt, SeD DiAm vOlUpTuA. aT V!!!
eRo eOs eT AcCuSaM Et jUsTo dUo dOlOrEs eT Ea rEbUm. StEt cLiTa kAsD GuBeRgReN!!!
nO SeA TaKiMaTa sAnCtUs eSt lOrEm iPsUm dOlOr sIt aMeT!!!

dUiS AuTeM VeL EuM IrIuRe dOlOr iN HeNdReRiT In vUlPuTaTe vElIt eSsE MoLeStIe cO!!!
nSeQuAt, VeL IlLuM DoLoRe eU FeUgIaT NuLlA FaCiLiSiS At vErO ErOs eT AcCuMsAn eT!!!
iUsTo oDiO DiGnIsSiM QuI BlAnDiT PrAeSeNt lUpTaTuM ZzRiL DeLeNiT AuGuE DuIs dOl!!!
OrE Te fEuGaIt nUlLa fAcIlIsI. lOrEm iPsUm dOlOr sIt aMeT, cOnSeCtEtUeR AdIpIsCi!!!
Ng eLiT, sEd dIaM NoNuMmY NiBh eUiSmOd tInCiDuNt uT LaOrEeT DoLoRe mAgNa aLiQuAm!!!
ErAt vOlUtPaT!!!

uT WiSi eNiM Ad mInIm vEnIaM, qUiS NoStRuD ExErCi tAtIoN UlLaMcOrPeR SuScIpIt lO!!!
bOrTiS NiSl uT AlIqUiP Ex eA CoMmOdO CoNsEqUaT. dUiS AuTeM VeL EuM IrIuRe dOlOr!!!
In hEnDrErIt iN VuLpUtAtE VeLiT EsSe mOlEsTiE CoNsEqUaT, vEl iLlUm dOlOrE Eu fEu!!!
GiAt nUlLa fAcIlIsIs aT VeRo eRoS Et aCcUmSaN Et iUsTo oDiO DiGnIsSiM QuI BlAnDi!!!
T PrAeSeNt lUpTaTuM ZzRiL DeLeNiT AuGuE DuIs dOlOrE Te fEuGaIt nUlLa fAcIlIsI!!!

aNd i wOuLd lIkE To tAlK To yOuR MaNaGeR!!!
karen@localhost:~$
```

### AcTiVaTe vIsUaL AsSiStAnT MoDe!!!

NoTe hOw tHe vIsUaL StAtEmEnT FoLlOwInG RaNdOm sEnTeNcEs mAkEs yOuR PoInT So!!!
MuCh cLeArEr:!!!

```console
karen@localhost:~$ head -1 lipsum.txt | fold | karentify --aCtInG-OuT
LoReM IpSuM DoLoR SiT AmEt, CoNsEtEtUr sAdIpScInG ElItR, sEd dIaM NoNuMy eIrMoD!!![nervous eye twitching]!!!
tEmPoR InViDuNt uT LaBoRe eT DoLoRe mAgNa aLiQuYaM ErAt, SeD DiAm vOlUpTuA. aT V!!!
eRo eOs eT AcCuSaM Et jUsTo dUo dOlOrEs eT Ea rEbUm. StEt cLiTa kAsD GuBeRgReN!!!
nO SeA TaKiMaTa sAnCtUs eSt lOrEm iPsUm dOlOr sIt aMeT!!!
karen@localhost:~$
```

### My cOdE CoMmEnTs nEeD To sHoW ThE ImPoRtAnCe oF ThE AlGoRiThM!!!

kArEnTiFy iS FuLlY Vi cOmPaTiBlE.  JuSt vIsUaLlY MaRk yOuR CoDe, ThEn pIpE It!!!
ThRoUgH KaReNtIfY UsInG `:!karentify<CR>`!!!

## UsAgE!!!

### cOmMaNd lInE InTeRfAcE!!!

tHe kArEnTiFy cOmMaNd lInE InTeRfAcE MaKeS StAtInG YoUr dEmAnDs aS EaSy aS!!!
TyPiNg tHeM InTo tHe pRoMpT Or aDdInG ThEm aS ArGuMeNtS!!!

tO EsCaLaTe iSsUeS FuRtHeR, uSe tHe `--dEmAnD-MaNaGeR` OpTiOn!!!

```console
karen@localhost:~$ karentify --dEmAnD-MaNaGeR i have never been treated like this

i hAvE NeVeR BeEn tReAtEd lIkE ThIs!!!
AnD I WoUlD LiKe tO TaLk tO YoUr mAnAgEr!!!
karen@localhost:~$
```

iT CaN AlSo bE UsEd aS A FiLtEr fRoM YoUr eDiToR.!!!

### aS A LiBrArY!!!

```python
from karentify import karentify

print(karentify('i have never been treated like this') + '!!!')
```

## InStAlLaTiOn!!!

wHy wOuLd i nEeD To dO ThAt?  iSn't tHaT WhAt sErViCe eMpLoYeEs aRe fOr?!!!

wElL!!!

### KaReNtIfY Is aVaIlAbLe oN PyPi!!!

```shell
pip install karentify
```

wIlL GiVe yOu bOtH ThE LiBrArY To eNhAnCe yOuR OwN PrOjEcT, aS WeLl aS ThE!!!
pOwErFuL CoMmAnDlInE UtIlItY!!!

### Bleeding edge development

If yOu wAnT To sTaY At tHe pUlSe oF TiMe, AlWaYs bEnEfItTiNg fRoM ThE LaTeSt!!!
AnD GrEaTeSt dEvElOpMeNtS, yOu cAn gEt kArEnTiFy dIrEcTlY FrOm gItHuB:!!!

https://github.com/dickerdackel/karentify

## bUgS!!!

BuG SuMbItTaL HaS To hApPeN ThRoUgH A MaNaGeR!!!

## mIsSiOn sTaTeMeNt!!!

We sTrIvE To mAkE ThE WoRlD A BeTtEr pLaCe.  kArEnTiFy iS OuR PaRt iN ThAt!!!

==> karentify-0.0.3.tar.gz: karentify-0.0.3/README.md <==
# ThIs iS KaReNtIfY!!!

uNlEaSh yOuR InNeR KaReN On a mEsSaGe!!!

mAkE SuRe, YoU ArE HeArD As a vAlUeD CuStOmEr bY UnLeAsHiNg yOuR InNeR KaReN!!!

## fEaTuReS!!!

* aLl sHoRt oPtIoNs aRe cApS OnLy!!!
* LoNg oPtIoNs aLl kArEnTiFiEd tO Be vErY ClEaR AbOuT ThEm!!!
* MuLtIpLe iNpUt fEeDs, Be iT!!!
  * ...tHaT YoU WaNt tO StAtE YoUr vAlId dEmAnDs dIrEcTlY On tHe cOmMaNdLiNe!!!
  * ...Or yOu wAnT To iNtErAcTiVeLy sTaTe tHeM!!!
  * ...oR YoU WaNt tO RaIsE ThE SeRiOuSnEsS In aN ExIsTiNg bOdY Of tExT!!!
* DoCuMeNtAtIoN CoMeS FrOm a pOiNt oF EdUcAtEd aUtHoRiTy!!!

kArEnTiFy hAs yOu cOvErEd!!!

## uSe cAsEs!!!

### I WaNt tO MaKe mY PoInT VeRy cLeAr:!!!

```console
karen@localhost:~$ karentify is that clear? --dEmAnD-MaNaGeR
iS ThAt cLeAr!!!
AnD I WoUlD LiKe tO TaLk tO YoUr mAnAgEr!!!
karen@localhost:~$
```

NoTe tHe fEaTuRe oF Ai aSsIsTeT AuToMaTiC DoUbT ReMoVaL!!!

### My lOnG FoRm tExT NeEdS AuThOrItY:!!!

```console
karen@localhost:~$ cat lipsum.txt | fold | karentify --dEmAnD-MaNaGeR
LoReM IpSuM DoLoR SiT AmEt, CoNsEtEtUr sAdIpScInG ElItR, sEd dIaM NoNuMy eIrMoD!!!
tEmPoR InViDuNt uT LaBoRe eT DoLoRe mAgNa aLiQuYaM ErAt, SeD DiAm vOlUpTuA. aT V!!!
eRo eOs eT AcCuSaM Et jUsTo dUo dOlOrEs eT Ea rEbUm. StEt cLiTa kAsD GuBeRgReN!!!
nO SeA TaKiMaTa sAnCtUs eSt lOrEm iPsUm dOlOr sIt aMeT!!!

dUiS AuTeM VeL EuM IrIuRe dOlOr iN HeNdReRiT In vUlPuTaTe vElIt eSsE MoLeStIe cO!!!
nSeQuAt, VeL IlLuM DoLoRe eU FeUgIaT NuLlA FaCiLiSiS At vErO ErOs eT AcCuMsAn eT!!!
iUsTo oDiO DiGnIsSiM QuI BlAnDiT PrAeSeNt lUpTaTuM ZzRiL DeLeNiT AuGuE DuIs dOl!!!
OrE Te fEuGaIt nUlLa fAcIlIsI. lOrEm iPsUm dOlOr sIt aMeT, cOnSeCtEtUeR AdIpIsCi!!!
Ng eLiT, sEd dIaM NoNuMmY NiBh eUiSmOd tInCiDuNt uT LaOrEeT DoLoRe mAgNa aLiQuAm!!!
ErAt vOlUtPaT!!!

uT WiSi eNiM Ad mInIm vEnIaM, qUiS NoStRuD ExErCi tAtIoN UlLaMcOrPeR SuScIpIt lO!!!
bOrTiS NiSl uT AlIqUiP Ex eA CoMmOdO CoNsEqUaT. dUiS AuTeM VeL EuM IrIuRe dOlOr!!!
In hEnDrErIt iN VuLpUtAtE VeLiT EsSe mOlEsTiE CoNsEqUaT, vEl iLlUm dOlOrE Eu fEu!!!
GiAt nUlLa fAcIlIsIs aT VeRo eRoS Et aCcUmSaN Et iUsTo oDiO DiGnIsSiM QuI BlAnDi!!!
T PrAeSeNt lUpTaTuM ZzRiL DeLeNiT AuGuE DuIs dOlOrE Te fEuGaIt nUlLa fAcIlIsI!!!

aNd i wOuLd lIkE To tAlK To yOuR MaNaGeR!!!
karen@localhost:~$
```

### AcTiVaTe vIsUaL AsSiStAnT MoDe!!!

NoTe hOw tHe vIsUaL StAtEmEnT FoLlOwInG RaNdOm sEnTeNcEs mAkEs yOuR PoInT So!!!
MuCh cLeArEr:!!!

```console
karen@localhost:~$ head -1 lipsum.txt | fold | karentify --aCtInG-OuT
LoReM IpSuM DoLoR SiT AmEt, CoNsEtEtUr sAdIpScInG ElItR, sEd dIaM NoNuMy eIrMoD!!![nervous eye twitching]!!!
tEmPoR InViDuNt uT LaBoRe eT DoLoRe mAgNa aLiQuYaM ErAt, SeD DiAm vOlUpTuA. aT V!!!
eRo eOs eT AcCuSaM Et jUsTo dUo dOlOrEs eT Ea rEbUm. StEt cLiTa kAsD GuBeRgReN!!!
nO SeA TaKiMaTa sAnCtUs eSt lOrEm iPsUm dOlOr sIt aMeT!!!
karen@localhost:~$
```

### My cOdE CoMmEnTs nEeD To sHoW ThE ImPoRtAnCe oF ThE AlGoRiThM!!!

kArEnTiFy iS FuLlY Vi cOmPaTiBlE.  JuSt vIsUaLlY MaRk yOuR CoDe, ThEn pIpE It!!!
ThRoUgH KaReNtIfY UsInG `:!karentify<CR>`!!!

## UsAgE!!!

### cOmMaNd lInE InTeRfAcE!!!

tHe kArEnTiFy cOmMaNd lInE InTeRfAcE MaKeS StAtInG YoUr dEmAnDs aS EaSy aS!!!
TyPiNg tHeM InTo tHe pRoMpT Or aDdInG ThEm aS ArGuMeNtS!!!

tO EsCaLaTe iSsUeS FuRtHeR, uSe tHe `--dEmAnD-MaNaGeR` OpTiOn!!!

```console
karen@localhost:~$ karentify --dEmAnD-MaNaGeR i have never been treated like this

i hAvE NeVeR BeEn tReAtEd lIkE ThIs!!!
AnD I WoUlD LiKe tO TaLk tO YoUr mAnAgEr!!!
karen@localhost:~$
```

iT CaN AlSo bE UsEd aS A FiLtEr fRoM YoUr eDiToR.!!!

### aS A LiBrArY!!!

```python
from karentify import karentify

print(karentify('i have never been treated like this') + '!!!')
```

## InStAlLaTiOn!!!

wHy wOuLd i nEeD To dO ThAt?  iSn't tHaT WhAt sErViCe eMpLoYeEs aRe fOr?!!!

wElL!!!

### KaReNtIfY Is aVaIlAbLe oN PyPi!!!

```shell
pip install karentify
```

wIlL GiVe yOu bOtH ThE LiBrArY To eNhAnCe yOuR OwN PrOjEcT, aS WeLl aS ThE!!!
pOwErFuL CoMmAnDlInE UtIlItY!!!

### Bleeding edge development

If yOu wAnT To sTaY At tHe pUlSe oF TiMe, AlWaYs bEnEfItTiNg fRoM ThE LaTeSt!!!
AnD GrEaTeSt dEvElOpMeNtS, yOu cAn gEt kArEnTiFy dIrEcTlY FrOm gItHuB:!!!

https://github.com/dickerdackel/karentify

## bUgS!!!

BuG SuMbItTaL HaS To hApPeN ThRoUgH A MaNaGeR!!!

## mIsSiOn sTaTeMeNt!!!

We sTrIvE To mAkE ThE WoRlD A BeTtEr pLaCe.  kArEnTiFy iS OuR PaRt iN ThAt!!!
